import { TemplateRef, ViewContainerRef } from '@angular/core';
export interface TemplateManager<C extends object, N extends string = string> {
    /**
     * @description
     * Mutates the inner viewContext with the passed object slice.
     *
     * @param viewContextSlice - the object holding the new state
     */
    updateViewContext(viewContextSlice: Partial<C>): void;
    /**
     * @description
     * Adds a template to the internal templateRefCache map.
     *
     * @param name
     * @param templateRef
     */
    addTemplateRef(name: N, templateRef: TemplateRef<C>): void;
    /**
     * @description
     * Checks if `TemplateRef` instance is cached under the provided name.
     */
    hasTemplateRef(name: N): boolean;
    /**
     * @description
     * Creates and inserts view out of registered templates and caches it for the later
     * re-usage.
     *
     * @param name name of the cached view
     */
    displayView(name: N): void;
    /**
     * @description
     * Clears all cached views. This should be called if the instance that holds the template manager dies.
     */
    destroy(): void;
}
/**
 * TemplateManager
 *
 * @description
 * This function returns an object that holds the logic for managing templates of a `ViewContainerRef`.
 * It abstracts `EmbeddedView` creation, `insert` calls and `ViewContext` updates.
 * Internally it creates template references lazily by combining caching logic and the `ViewContainerRef#detach` method.
 * The `TemplateManager` lets you re-use templates and insert views on-demand, as well as update the view context
 * (e.g. when a new observable notification is sent).
 *
 * @param viewContainerRef reference to a top-level view container where passed templates will be attached
 * @param initialViewContext initial view context state
 */
export declare function createTemplateManager<C extends object, N extends string = string>(viewContainerRef: ViewContainerRef, initialViewContext: C): TemplateManager<C, N>;
