import { RenderStrategy, RenderStrategyFactoryConfig } from '../../core/render-aware';
/**
 * Detach Strategies
 *
 * | Name      | Zone Agnostic | Render Method     | Coalescing         | Scheduling                 |
 * | --------- | --------------| ----------------- | ------------------ | -------------------------- |
 * | `detach`  | ✔             | ⭭ `detectChanges` | ✔ ComponentContext | `requestAnimationFrame`   |
 *
 */
export declare function getDetachStrategies<T>(config: RenderStrategyFactoryConfig): {
    [strategy: string]: RenderStrategy;
};
/**
 * Detach Strategy
 *
 * This strategy behaves the same as the local strategy.
 * The detach strategy detaches the component from Angulars change detection.
 * With every new value it re-attaches the component/embedded view to the change detection,
 * renders the new value and detaches again.
 *
 * If a component is detached the input bindings will still receive values.
 * Also the internal logic will work as expected including the use of `ViewChild`.
 * Only the template will not be updated.
 *
 * | Name      | Zone Agnostic | Render Method     | Coalescing         | Scheduling                 |
 * | --------- | --------------| ----------------- | ------------------ | -------------------------- |
 * | `detach`  | ✔             | ⭭ `detectChanges` | ✔ ComponentContext | `requestAnimationFrame`   |
 *
 * @param config - The values this strategy needs to get calculated.
 * @return - The calculated strategy
 *
 */
export declare function createDetachStrategy(config: RenderStrategyFactoryConfig): RenderStrategy;
