import { RenderStrategy, RenderStrategyFactoryConfig } from '../../core/render-aware';
export declare const DEFAULT_STRATEGY_NAME = "local";
/**
 * @description
 * This method returns the provided strategies as name:strategy pair
 *
 * Built-in Strategies:
 *
 * | Name      | Zone Agnostic | Render Method     | Coalescing         | Scheduling                 |
 * | --------- | --------------| ----------------- | ------------------ | -------------------------- |
 * | `local`   | ✔             | 🠗 `detectChanges` | ✔ ComponentContext | `requestAnimationFrame`   |
 * | `global`  | ✔             | ⮁ `ɵmarkDirty`    | ✔ RootContext     | `requestAnimationFrame`   |
 * | `detach`  | ✔             | ⭭ `detectChanges` | ✔ ComponentContext | `requestAnimationFrame`   |
 * | `noop`    | ✔             | - `noop`          | ❌                 | ❌                        |
 * | `native`  | ❌             | ⮁ `markForCheck` | ✔ RootContext     | `requestAnimationFrame`  |
 *
 * @param config
 */
export declare function getStrategies(config: RenderStrategyFactoryConfig): {
    [strategy: string]: RenderStrategy;
};
